/*
 *	Program Lock Sample
 *	Copyright (c) 1994 Robust Software
 *
 *	PROGLOCK module
 *	This is a very simplistic program which demonstrates the use of the
 *	Software Copy Protection's Program Locks.
 *
 */

#include <windows.h>
#include "codelock.h"

LONG FAR PASCAL MainWndProc(HWND hWnd, unsigned msg, WORD wParam,
	LONG lParam);

HANDLE hInst;
char gszProductID[] = "proglock";

int PASCAL WinMain(HANDLE hInstance, HANDLE hPrevInstance, LPSTR lpCmdLine,
	int nCmdShow)
{
	MSG msg;

	if (CheckProgramLock(gszProductID, "secret") == CODELOCK_FAILURE) {
		MessageBox(NULL, "Program lock is broken", "Program Lock Sample",
			MB_OK);
		return 1;
	}
	hInst = hInstance;
	if (!hPrevInstance)
		if (!InitApplication(hInstance))
			return FALSE;
	if (!InitInstance(hInstance, nCmdShow))
		return FALSE;

	while (GetMessage(&msg, NULL, NULL, NULL)) {
		TranslateMessage(&msg);
		DispatchMessage(&msg);
	}
	return msg.wParam;
}

/*
 * InitApplication
 *
 * Description:
 *	Registers the window class.
 *
 * Inputs:	hInstance
 * Outputs:	TRUE or FALSE
 */

BOOL InitApplication(HANDLE hInstance)
{
	WNDCLASS wc;

	wc.style = 0;
	wc.lpfnWndProc = MainWndProc;
	wc.cbClsExtra = 0;
	wc.cbWndExtra = 0;
	wc.hInstance = hInstance;
	wc.hIcon = LoadIcon(NULL, IDI_APPLICATION);
	wc.hCursor = LoadCursor(NULL, IDC_ARROW);
	wc.hbrBackground = GetStockObject(WHITE_BRUSH);
	wc.lpszMenuName = NULL;
	wc.lpszClassName = "TestClass";
	if (RegisterClass(&wc) == FALSE)
		return FALSE;
	return TRUE;
}

/*
 * InitInstance
 *
 * Description:
 *	Creates the program's window.
 *
 * Inputs:	hInstance, nCmdShow
 * Outputs:	TRUE or FALSE
 */

BOOL InitInstance(HANDLE hInstance, WORD nCmdShow)
{
	HWND hWnd;

	hWnd = CreateWindow("TestClass", "Program Lock Sample", WS_OVERLAPPEDWINDOW,
		CW_USEDEFAULT, CW_USEDEFAULT, CW_USEDEFAULT, CW_USEDEFAULT, NULL,
		NULL, hInstance, NULL);

	if (!hWnd)
		return FALSE;

	ShowWindow(hWnd, nCmdShow);
	UpdateWindow(hWnd);
	return TRUE;
}

/*
 * MainWndProc
 *
 * Description:
 *	Main window Proc.
 *
 * Input:	Standard Window Proc.
 * Outputs:	None.
 */

LONG FAR PASCAL MainWndProc(HWND hWnd, unsigned msg, WORD wParam,
	LONG lParam)
{
	switch (msg) {
	case WM_DESTROY:
		PostQuitMessage(0);
		break;

	case WM_CLOSE:
		PostQuitMessage(0);
		return FALSE;

	default:
		return DefWindowProc(hWnd, msg, wParam, lParam);
	}
	return FALSE;
}
